diff target-utils/libtiffs/globals.h @ 60:87cb03b35f77

target-utils: long-overdue s/mpffs/tiffs/ and s/MPFFS/TIFFS/ rename
author Mychaela Falconia <falcon@freecalypso.org>
date Wed, 26 Oct 2016 15:52:14 +0000
parents e7502631a0f9
children
line wrap: on
line diff
--- a/target-utils/libtiffs/globals.h	Wed Oct 26 15:28:29 2016 +0000
+++ b/target-utils/libtiffs/globals.h	Wed Oct 26 15:52:14 2016 +0000
@@ -1,9 +1,9 @@
 /* global variables for the MPFFS reader code - extern declarations */
 
-extern struct inode *mpffs_active_index;
-extern int mpffs_root_ino;
-extern int mpffs_init_done;
+extern struct inode *tiffs_active_index;
+extern int tiffs_root_ino;
+extern int tiffs_init_done;
 
-extern const u32 mpffs_base_addr;
-extern const u32 mpffs_sector_size;
-extern const int mpffs_nsectors;
+extern const u32 tiffs_base_addr;
+extern const u32 tiffs_sector_size;
+extern const int tiffs_nsectors;
@@ -1,9 +1,9 @@
-/* global variables for the MPFFS reader code - extern declarations */
+/* global variables for the TIFFS reader code - extern declarations */
 